@@ -7,11 +7,15 @@ from pyduinocli.commands.core import CoreCommand
 from pyduinocli.commands.daemon import DaemonCommand
 from pyduinocli.commands.debug import DebugCommand
 from pyduinocli.commands.lib import LibCommand
+from pyduinocli.commands.monitor import MonitorCommand
 from pyduinocli.commands.sketch import SketchCommand
 from pyduinocli.commands.upload import UploadCommand
 from pyduinocli.commands.version import VersionCommand
 from pyduinocli.commands.burn_bootloader import BurnBootloaderCommand
 from pyduinocli.commands.completion import CompletionCommand
+from pyduinocli.commands.outdated import OutdatedCommand
+from pyduinocli.commands.update import UpdateCommand
+from pyduinocli.commands.upgrade import UpgradeCommand
 from pyduinocli.constants import flags
 
 
@@ -25,9 +29,9 @@ class ArduinoCliCommand(CommandBase):
     __FORMAT_JSON = 'json'
 
     def __init__(self, cli_path="arduino-cli", config_file=None, additional_urls=None, log_file=None, log_format=None,
-                 log_level=None):
+                 log_level=None, no_color=None):
         """
-        :param cli_path: The :code:`arduino-cli` command name if available in :code:`$PATH`. Can also be a direct path the the executable
+        :param cli_path: The :code:`arduino-cli` command name if available in :code:`$PATH`. Can also be a direct path to the executable
         :type cli_path: str
         :param config_file: The path to the :code:`arduino-cli` configuration file to be used
         :type config_file: str or NoneType
@@ -39,6 +43,8 @@ class ArduinoCliCommand(CommandBase):
         :type log_format: str or NoneType
         :param log_level: The log level for the log file
         :type log_level: str or NoneType
+        :param no_color: Disable colored output
+        :type no_color: bool or NoneType
         """
         base_args = [cli_path, flags.FORMAT, ArduinoCliCommand.__FORMAT_JSON]
         if config_file:
@@ -51,6 +57,8 @@ class ArduinoCliCommand(CommandBase):
             base_args.extend([flags.LOG_FORMAT, CommandBase._strip_arg(log_format)])
         if log_level:
             base_args.extend([flags.LOG_LEVEL, CommandBase._strip_arg(log_level)])
+        if no_color is True:
+            base_args.append(flags.NO_COLOR)
         CommandBase.__init__(self, base_args)
         self.__board = BoardCommand(self._base_args)
         self.__cache = CacheCommand(self._base_args)
@@ -65,6 +73,10 @@ class ArduinoCliCommand(CommandBase):
         self.__version = VersionCommand(self._base_args)
         self.__burn_bootloader = BurnBootloaderCommand(self._base_args)
         self.__completion = CompletionCommand(self._base_args)
+        self.__outdated = OutdatedCommand(self._base_args)
+        self.__update = UpdateCommand(self._base_args)
+        self.__upgrade = UpgradeCommand(self._base_args)
+        self.__monitor = MonitorCommand(self._base_args)
 
     @property
     def board(self):
@@ -182,3 +194,39 @@ class ArduinoCliCommand(CommandBase):
         :type: :class:`pyduinocli.commands.completion.CompletionCommand`
         """
         return self.__completion
+
+    @property
+    def outdated(self):
+        """
+        The outdated command wrapper for this :code:`arduino-cli` wrapper
+
+        :type: :class:`pyduinocli.commands.outdated.OutdatedCommand`
+        """
+        return self.__outdated
+
+    @property
+    def update(self):
+        """
+        The update command wrapper for this :code:`arduino-cli` wrapper
+
+        :type: :class:`pyduinocli.commands.update.UpdateCommand`
+        """
+        return self.__update
+
+    @property
+    def upgrade(self):
+        """
+        The upgrade command wrapper for this :code:`arduino-cli` wrapper
+
+        :type: :class:`pyduinocli.commands.upgrade.UpgradeCommand`
+        """
+        return self.__upgrade
+
+    @property
+    def monitor(self):
+        """
+        The monitor command wrapper for this :code:`arduino-cli` wrapper
+
+        :type: :class:`pyduinocli.commands.monitor.MonitorCommand`
+        """
+        return self.__monitor
